ledger : Accounting — amici1

# `ledger` : Accounting

See also `lino_xl.lib.ledger`.

## Models

## Actors

- Booking directions : (no docstring)

- Journal groups : (no docstring)

- States : (no docstring)

- Common accounts : (no docstring)

- Voucher types : (no docstring)

- Trade types : (no docstring)

- Voucher states : (no docstring)

- Content : (no docstring)

- Partner vouchers : Shows all ledger vouchers of a given partner.

- Accounts : (no docstring)

- Journals : (no docstring)

- Journals : (no docstring)

- ByJournal : (no docstring)

- PrintableByJournal : (no docstring)

- Accounting periods : (no docstring)

- Payment terms : (no docstring)

- Payment methods : (no docstring)

- Vouchers : (no docstring)

- Vouchers : (no docstring)

- Match rules : (no docstring)

- Match rules : (no docstring)

- Match rules : (no docstring)

- Debts : (no docstring)

- Debts : (no docstring)

- Debts : (no docstring)

- Vouchers : (no docstring)

- AccountBalances : (no docstring)

- General Account Balances : (no docstring)

- Partners : (no docstring)

- DebtorsCreditors : (no docstring)

- Debtors : (no docstring)

- Creditors : (no docstring)

- Movements : (no docstring)

- Movements : (no docstring)

- Movements : (no docstring)

- Movements : (no docstring)

- My movements : (no docstring)

- Movements : (no docstring)

- Movements : (no docstring)

- Movements : (no docstring)

- Fiscal years : (no docstring)

- ledger infos : (no docstring)